pub struct ScrambleMutator { /* private fields */ }Expand description
The ScrambleMutator is a simple mutator that scrambles a random section of the [Chromosome].
Because the slice of the chromosome is of random length, with small chromosomes, the scrambling may not be very effective. This mutator is best used with larger [Chromosome]s.
Implementations
Sourceimpl ScrambleMutator
impl ScrambleMutator
pub fn new(rate: impl Into<Expr>) -> ScrambleMutator