FloatGene

Struct FloatGene 

pub struct FloatGene<F>
where F: Float,
{ /* private fields */ }
A Gene that represents a floating point number. The allele is the in the case of the FloatGene is of type F - which is a floating point type. The min and max values default to F::MIN and F::MAX respectively. During evolution, the value_range is used to generate new allele values, while the bounds are used to ensure that the allele remains within a valid range. If no bounds are provided, they default to the same values as value_range.

Example

use radiate_core::*;

// Create a new FloatGene with a min value of 0 and a max value of 1 meaning the
// allele will be a random number between 0 and 1.
// The upper_bound and lower_bound are set to 0 and 1 respectively.
let gene = FloatGene::from(0_f32..1_f32);

// Create a new FloatGene with a min of 0 and a max of 1 and set the upper_bound
// and lower_bound to 0 and 100 respectively.
let gene = FloatGene::from((0_f32..1_f32, 0_f32..100_f32));

Implementations

Source

impl<F> FloatGene<F>
where F: Float,

pub fn new(allele: F, value_range: Range<F>, bounds: Range<F>) -> FloatGene<F>

Creates a new FloatGene with the given allele, value_range, and bounds.