pub struct BlendCrossover { /* private fields */ }Expand description
The BlendCrossover is a crossover operator that blends [FloatGene] alleles from two parent chromosomes to create offspring.
The blending is controlled by the alpha parameter, which determines the extent of blending between the two alleles.
The formula used for blending is:
new_allele_one = allele_one - (alpha * (allele_two - allele_one))
new_allele_two = allele_two - (alpha * (allele_one - allele_two))Implementations
Sourceimpl BlendCrossover
impl BlendCrossover
Sourcepub fn new(rate: impl Into<Rate>, alpha: f32) -> BlendCrossover
pub fn new(rate: impl Into<Rate>, alpha: f32) -> BlendCrossover
Create a new instance of the BlendCrossover with the given rate and alpha. The rate must be between 0.0 and 1.0, and the alpha must be between 0.0 and 1.0.