pub struct GaussianMutator { /* private fields */ }Expand description
The GaussianMutator is a simple mutator that adds a small amount of Gaussian noise to the gene.
This mutator is for use with any Chromosome which holds FloatGenes.
Implementations
Sourceimpl GaussianMutator
impl GaussianMutator
Sourcepub fn new(rate: impl Into<Rate>) -> GaussianMutator
pub fn new(rate: impl Into<Rate>) -> GaussianMutator
Create a new instance of the GaussianMutator with the given rate.
The rate must be between 0.0 and 1.0.