pub struct Phenotype<C>where
C: Chromosome,{ /* private fields */ }Expand description
A Phenotype is a representation of an individual in the population. It contains:
Genotype- the genetic representation of the individualScore- the score (fitness) of the individual as calculated by the fitness functionGeneration- the generation in which the individual was createdid- a unique identifier for the Phenotype
The Phenotype is a wrapper around the Genotype that adds additional information about the individual. In traditional (biological) genetics, a phenotype is “the set of observable characteristics of an individual resulting from the interaction of its genotype with the environment”. As such, the Phenotype is the ‘observable’ part of the individual (Genotype) that is being evolved by the genetic algorithm, hence the Score and generation fields. This allows the Phenotype to be sorted and compared based on the fitness (Score) of the individual (Genotype)
Type Parameters
C: The type of chromosome used in the genotype, which must implement theChromosometrait.
Implementations
Sourceimpl<C> Phenotype<C>where
C: Chromosome,
impl<C> Phenotype<C>where
C: Chromosome,
pub fn genotype(&self) -> &Genotype<C>
pub fn genotype_mut(&mut self) -> &mut Genotype<C>
pub fn take_genotype(&mut self) -> Result<Genotype<C>, RadiateError>
pub fn set_genotype(&mut self, genotype: Genotype<C>)
pub fn set_score(&mut self, score: Option<Score>)
pub fn generation(&self) -> usize
pub fn score(&self) -> Option<&Score>
pub fn id(&self) -> PhenotypeId
pub fn family(&self) -> FamilyId
pub fn invalidate(&mut self, generation: usize)